Package: BayesRTMB
Type: Package
Title: Bayesian Inference Using 'RTMB'
Version: 0.1.1
Authors@R: person("Hiroshi", "Shimizu", email = "simizu706@gmail.com", role = c("aut", "cre"))
Description: Provides tools for Markov chain Monte Carlo (MCMC) and Maximum A Posteriori (MAP) estimation utilizing the 'RTMB' package. It supports various statistical models including generalized linear mixed models, factor analysis, item response theory, and multidimensional unfolding. The package allows users to easily transition between frequentist and Bayesian paradigms using a unified interface. Automatic differentiation and Laplace approximation follow Kristensen et al. (2016) <doi:10.18637/jss.v070.i05>, and MCMC sampling uses the No-U-Turn Sampler described by Hoffman and Gelman (2014) <https://jmlr.org/papers/v15/hoffman14a.html>.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
LazyData: true
Depends: R (>= 4.1.0), RTMB
Imports: R6, MASS
URL: https://github.com/norimune/BayesRTMB,
        https://norimune.github.io/BayesRTMB/
BugReports: https://github.com/norimune/BayesRTMB/issues
Suggests: knitr, rmarkdown, GPArotation, future, future.apply,
        progressr
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-28 07:39:58 UTC; norimune
Author: Hiroshi Shimizu [aut, cre]
Maintainer: Hiroshi Shimizu <simizu706@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-01 08:40:26 UTC
