# Generated by roxygen2: do not edit by hand

S3method(AIC,Classic_Fit)
S3method(BIC,Classic_Fit)
S3method(anova,Classic_Fit)
S3method(conditional_effects,advi_fit)
S3method(conditional_effects,default)
S3method(conditional_effects,map_fit)
S3method(conditional_effects,mcmc_fit)
S3method(conditional_effects,vb_fit)
S3method(item_curve,RTMB_Fit_Base)
S3method(item_curve,advi_fit)
S3method(item_curve,map_fit)
S3method(item_curve,mcmc_fit)
S3method(item_info,RTMB_Fit_Base)
S3method(item_info,advi_fit)
S3method(item_info,map_fit)
S3method(item_info,mcmc_fit)
S3method(logLik,Classic_Fit)
S3method(lsmeans,Classic_Fit)
S3method(plot,ce_rtmb)
S3method(plot,rtmb_item_curve)
S3method(plot,rtmb_item_info)
S3method(plot,rtmb_lsmeans)
S3method(plot,rtmb_test_info)
S3method(print,Classic_Fit)
S3method(print,anova_classic_lm_f)
S3method(print,anova_classic_lrt)
S3method(print,anova_rtmb)
S3method(print,anova_rtmb_table)
S3method(print,bayes_factor)
S3method(print,bayes_factor_rtmb)
S3method(print,ce_rtmb)
S3method(print,ce_simple)
S3method(print,diagnose_BayesRTMB)
S3method(print,map_fit)
S3method(print,rtmb_estimate_matrix)
S3method(print,rtmb_item_curve)
S3method(print,rtmb_item_info)
S3method(print,rtmb_lrt_two_stage)
S3method(print,rtmb_lsmeans)
S3method(print,rtmb_lsmeans_grouped)
S3method(print,rtmb_test_info)
S3method(print,summary_BayesRTMB)
S3method(print,summary_Classic_Fit)
S3method(print,waic_BayesRTMB)
S3method(simple_effects,advi_fit)
S3method(simple_effects,map_fit)
S3method(simple_effects,mcmc_fit)
S3method(simple_effects,vb_fit)
S3method(summary,Classic_Fit)
S3method(summary,ce_rtmb)
S3method(summary,map_fit)
S3method(test_info,RTMB_Fit_Base)
S3method(test_info,advi_fit)
S3method(test_info,map_fit)
S3method(test_info,mcmc_fit)
export(Classic_Fit)
export(Dim)
export(MAP_Fit)
export(MCMC_Fit)
export(RTMB_Fit_Base)
export(RTMB_Model)
export(VB_Fit)
export(bayes_factor)
export(conditional_effects)
export(distance)
export(ess_basic)
export(ess_bulk)
export(ess_tail95)
export(fabs)
export(gaussian_process_lpdf)
export(inv_logit)
export(item_curve)
export(item_info)
export(log1m)
export(log1m_exp)
export(log1p_exp)
export(log_det_chol)
export(log_mix)
export(log_softmax)
export(log_sum_exp)
export(log_sum_exp_matrix)
export(logit)
export(lsmeans)
export(make_bw_from_ydif)
export(make_glmer_Z_matrix)
export(make_glmer_re_terms)
export(make_init_mdu)
export(make_ydif_from_bw)
export(map_est)
export(plot_acf)
export(plot_conditional_effects)
export(plot_dens)
export(plot_forest)
export(plot_item_curve)
export(plot_item_info)
export(plot_lsmeans)
export(plot_mdu)
export(plot_pairs)
export(plot_test_info)
export(plot_trace)
export(prior_flat)
export(prior_jzs)
export(prior_normal)
export(prior_rhs)
export(prior_ssp)
export(prior_uniform)
export(prior_weak)
export(quad_form_chol)
export(quad_form_diag)
export(quantile95)
export(r_hat)
export(read_mcmc_csv)
export(restore_bw_from_ydif)
export(rtmb_code)
export(rtmb_corr)
export(rtmb_fa)
export(rtmb_glm)
export(rtmb_glmer)
export(rtmb_irt)
export(rtmb_lm)
export(rtmb_lmer)
export(rtmb_loglinear)
export(rtmb_lrt)
export(rtmb_mdu)
export(rtmb_mediation)
export(rtmb_mixture)
export(rtmb_model)
export(rtmb_table)
export(rtmb_ttest)
export(safe_rtmb_model)
export(simple_effects)
export(softmax)
export(sort_loadings)
export(squared_distance)
export(stz_basis)
export(sum_to_zero)
export(test_info)
export(to_centered_matrix)
export(to_centered_tri)
export(to_long)
export(to_wide)
import(MASS)
import(RTMB)
importFrom(R6,R6Class)
importFrom(grDevices,col2rgb)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,mtext)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,.getXlevels)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,Gamma)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,binomial)
importFrom(stats,chisq.test)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,delete.response)
importFrom(stats,density)
importFrom(stats,dunif)
importFrom(stats,fisher.test)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,poisson)
importFrom(stats,prcomp)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rchisq)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,getFromNamespace)
importFrom(utils,modifyList)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
