% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/math_functions.R
\name{stz_basis}
\alias{stz_basis}
\title{stz basis function}
\usage{
stz_basis(K)
}
\arguments{
\item{K}{A numeric value}
}
\value{
A transformation matrix
}
\description{
stz basis function
}
