% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/math_functions.R
\name{logit}
\alias{logit}
\title{Logit function}
\usage{
logit(x)
}
\arguments{
\item{x}{A numeric vector of probabilities.}
}
\value{
The logit of x.
}
\description{
Logit function
}
