% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods_post_estimation.R
\name{item_info.RTMB_Fit_Base}
\alias{item_info.RTMB_Fit_Base}
\title{Item Information Function for RTMB_Fit_Base}
\usage{
\method{item_info}{RTMB_Fit_Base}(x, theta_seq = seq(-4, 4, length.out = 100), items = NULL, ...)
}
\arguments{
\item{x}{An object of class RTMB_Fit_Base.}

\item{theta_seq}{Sequence of trait values (ability) to evaluate.}

\item{items}{Index or item names to restrict the calculation to specific items (optional).}

\item{...}{Additional arguments.}
}
\description{
Item Information Function for RTMB_Fit_Base
}
