% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distributions.R
\name{gaussian_process_lpdf}
\alias{gaussian_process_lpdf}
\title{Gaussian Process Log-Density (Squared Exponential Kernel)}
\usage{
gaussian_process_lpdf(
  y,
  x,
  mean = 0,
  magnitude = 1,
  smoothing = 1,
  noise = 0.01,
  sum = TRUE
)
}
\arguments{
\item{y}{Observation vector (N).}

\item{x}{Coordinate vector or matrix (N x D).}

\item{mean}{Mean vector (scalar or length N).}

\item{magnitude}{Signal standard deviation (alpha).}

\item{smoothing}{Length-scale (rho).}

\item{noise}{Measurement noise standard deviation (sigma).}

\item{sum}{Logical; whether to return the sum of log-densities.}
}
\value{
Log-density value.
}
\description{
Calculates the log-density of a Gaussian Process with a Squared Exponential (RBF) kernel.
}
