% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/math_functions.R
\name{inv_logit}
\alias{inv_logit}
\title{Inverse logit function}
\usage{
inv_logit(x)
}
\arguments{
\item{x}{A numeric vector.}
}
\value{
The inverse logit of x.
}
\description{
Inverse logit function
}
