% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot_forest}
\alias{plot_forest}
\title{Plot parameter estimates and credible intervals (Forest Plot)}
\usage{
plot_forest(
  x,
  prob = 0.95,
  point_estimate = c("median", "EAP", "mean", "MAP", "marginal_map", "joint_map")
)
}
\arguments{
\item{x}{A 3D array of posterior samples with dimensions `(iterations, chains, variables)`.}

\item{prob}{Numeric. Probability mass for the credible interval (default is 0.95).}

\item{point_estimate}{Character. Point estimate shown as dots. One of
`"median"` (default), `"EAP"`/`"mean"`, `"MAP"`/`"marginal_map"`, or
`"joint_map"`. `"joint_map"` uses the draw with the largest `lp` variable.}
}
\value{
No return value.
}
\description{
Plot parameter estimates and credible intervals (Forest Plot)
}
