% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot_conditional_effects}
\alias{plot_conditional_effects}
\title{Plot conditional effects}
\usage{
plot_conditional_effects(fit, effect, ...)
}
\arguments{
\item{fit}{A fitted model object (e.g., `MCMC_Fit`, `MAP_Fit`, `VB_Fit`).}

\item{effect}{Name of the variable to visualize (e.g., "X1" or "X1:X2").}

\item{...}{Additional arguments passed to \code{\link{conditional_effects}} or the plot method.}
}
\value{
Invisibly returns the plotted object of class \code{ce_rtmb}.
}
\description{
Calculate and plot conditional effects for a fitted model.
}
