% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classic.R
\name{lsmeans}
\alias{lsmeans}
\title{Least Squares Means (Marginal Means)}
\usage{
lsmeans(object, specs, ...)
}
\arguments{
\item{object}{A fitted model object (e.g., `Classic_Fit`).}

\item{specs}{A character vector of factor names to calculate means for.}

\item{...}{Additional arguments passed to the method.}
}
\description{
Calculate least squares means (also known as marginal means or predicted means)
for categorical factors in a fitted model. It also supports pairwise comparisons
and simple main effects.
}
