% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot_pairs}
\alias{plot_pairs}
\title{Plot pairs for posterior samples}
\usage{
plot_pairs(x, pars = NULL)
}
\arguments{
\item{x}{A 3D array of posterior samples with dimensions `(iterations, chains, variables)`.}

\item{pars}{Character vector or integer vector specifying which parameters to plot.
If NULL (default), up to the first 10 parameters are plotted to prevent overplotting.}
}
\value{
No return value.
}
\description{
Draw a scatterplot matrix to examine posterior correlations between parameters.
}
