% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/math_functions.R
\name{log1m}
\alias{log1m}
\title{Log of one minus x}
\usage{
log1m(x)
}
\arguments{
\item{x}{A numeric vector.}
}
\value{
The natural logarithm of 1 - x.
}
\description{
Log of one minus x
}
